@@ -35,6 +35,8 @@ sub slice {
     $end ||= $start;
 
     my $count = $end - $start + 1;
+    $count = 1 if $count < 1;
+    $start = 0 if $start < 0;
     my $sql = $self->sql . sprintf ' LIMIT %d, %d', $start, $count;
     my $sth = $self->class->db_Main->prepare($sql);
     $self->class->sth_to_objects($sth, $self->{_args});
